==> 1.0.2_20240315_release.zip: app/db/D_module.php <==
<?php

namespace app\db;

class D_module
{
    /**
     * 信息格式化
     */
    protected function detailed($Result, $format=1)
    {
        // 创建时间
        if (isset($Result['createTime'])) {
            $Result['createTimeFormat'] = app("ltcmsTime")::getDateTime('Y-m-d H:i:s', $Result['createTime']);
        }
        // 更新时间
        if (isset($Result['updateTime'])) {
            $Result['updateTimeFormat'] = app("ltcmsTime")::getDateTime('Y-m-d H:i:s', $Result['updateTime']);
        }
        // 安装时间
        if (isset($Result['installTime'])) {
            $Result['installTimeFormat'] = app("ltcmsTime")::getDateTime('Y-m-d H:i:s', $Result['installTime']);
        }
        // 状态
        if (isset($Result['disabled'])) {
            $disabledMap = array();
            $disabledMap["1"] = "开启";
            $disabledMap["0"] = "禁用";
            $Result['disabledFormat'] = isset($disabledMap[$Result['disabled']]) ? $disabledMap[$Result['disabled']] : "";
        }
        // 是否新窗口打开
        if (isset($Result['isBlank'])) {
            $isBlankMap = array();
            $isBlankMap["1"] = "是";
            $isBlankMap["0"] = "否";
            $Result['isBlankFormat'] = isset($isBlankMap[$Result['isBlank']]) ? $isBlankMap[$Result['isBlank']] : "";
        }
        // 是否是菜单
        if (isset($Result['isMenu'])) {
            $isMenuMap = array();
            $isMenuMap["1"] = "是";
            $isMenuMap["0"] = "否";
            $Result['isMenuFormat'] = isset($isMenuMap[$Result['isMenu']]) ? $isMenuMap[$Result['isMenu']] : "";
        }
        // 是否是链接
        if (isset($Result['isLink'])) {
            $isLinkMap = array();
            $isLinkMap["1"] = "是";
            $isLinkMap["0"] = "否";
            $Result['isLinkFormat'] = isset($isMenuMap[$Result['isLink']]) ? $isMenuMap[$Result['isLink']] : "";
        }
        // 类型
        if (isset($Result['module'])) {
            $moduleMap = array();
            $moduleMap["article"] = "文章";
            $moduleMap["extend"] = "扩展";
            $Result['moduleFormat'] = isset($moduleMap[$Result['module']]) ? $moduleMap[$Result['module']] : "";
        }
        // 链接地址
        $Result['useLinkUrl']=moduleLinkUrl($Result);
        // 返回结果
        return $Result;
    }
}

==> 1.0.20_20240718_release.zip: app/db/D_module.php <==
<?php

namespace app\db;

class D_module
{
    /**
     * 信息格式化
     */
    protected function detailed($Result, $format=1)
    {
        // 创建时间
        if (isset($Result['createTime'])) {
            $Result['createTimeFormat'] = app("ltcmsTime")::getDateTime('Y-m-d H:i:s', $Result['createTime']);
        }
        // 更新时间
        if (isset($Result['updateTime'])) {
            $Result['updateTimeFormat'] = app("ltcmsTime")::getDateTime('Y-m-d H:i:s', $Result['updateTime']);
        }
        // 安装时间
        if (isset($Result['installTime'])) {
            $Result['installTimeFormat'] = app("ltcmsTime")::getDateTime('Y-m-d H:i:s', $Result['installTime']);
        }
        // 状态
        if (isset($Result['disabled'])) {
            $disabledMap = array();
            $disabledMap["1"] = "开启";
            $disabledMap["0"] = "禁用";
            $Result['disabledFormat'] = isset($disabledMap[$Result['disabled']]) ? $disabledMap[$Result['disabled']] : "";
        }
        // 是否新窗口打开
        if (isset($Result['isBlank'])) {
            $isBlankMap = array();
            $isBlankMap["1"] = "是";
            $isBlankMap["0"] = "否";
            $Result['isBlankFormat'] = isset($isBlankMap[$Result['isBlank']]) ? $isBlankMap[$Result['isBlank']] : "";
        }
        // 是否是菜单
        if (isset($Result['isMenu'])) {
            $isMenuMap = array();
            $isMenuMap["1"] = "是";
            $isMenuMap["0"] = "否";
            $Result['isMenuFormat'] = isset($isMenuMap[$Result['isMenu']]) ? $isMenuMap[$Result['isMenu']] : "";
        }
        // 是否是链接
        if (isset($Result['isLink'])) {
            $isLinkMap = array();
            $isLinkMap["1"] = "是";
            $isLinkMap["0"] = "否";
            $Result['isLinkFormat'] = isset($isMenuMap[$Result['isLink']]) ? $isMenuMap[$Result['isLink']] : "";
        }
        // 类型
        if (isset($Result['module'])) {
            $moduleMap = array();
            $moduleMap["article"] = "文章";
            $moduleMap["extend"] = "扩展";
            $moduleMap["shop"] = "商城";
            $moduleMap["upgrade_log"] = "升级日志";
            $Result['moduleFormat'] = isset($moduleMap[$Result['module']]) ? $moduleMap[$Result['module']] : "";
        }
        // 返回结果
        return $Result;
    }
}
